# Autogenerated by devscripts/update-version.py

__version__ = '2026.03.17'

RELEASE_GIT_HEAD = '04d6974f502bbdfaed72c624344f262e30ad9708'

VARIANT = None

UPDATE_HINT = None

CHANNEL = 'stable'

ORIGIN = 'yt-dlp/yt-dlp'

_pkg_version = '2026.03.17'
